@@ -1,11 +1,8 @@
 ## no critic (Modules::RequireExplicitPackage)
 
 package OCS::Client;
-{
-  $OCS::Client::VERSION = '0.011';
-}
 # ABSTRACT: simple interface to OCS's SOAP API
-
+$OCS::Client::VERSION = '0.012';
 use utf8;
 use strict;
 use warnings;
@@ -106,9 +103,11 @@ my %fields = (
     21 => 'Office',
     22 => 'Office Tag',
     23 => 'PA',
+    25 => 'Nagios',
     26 => 'Diretoria',
     27 => 'Nota Fiscal',
     28 => 'HW Guidelines',
+    29 => 'Físico/Virtual',
 );
 
 
@@ -122,7 +121,7 @@ sub prune {
                 if (exists $fields{$1}) {
                     $myinfo{$fields{$1}} = $info->{content};
                 } else {
-                    carp "Skipping unknown ACCOUNTINFO field id: $1";
+                    carp "Skipping unknown ACCOUNTINFO field for $key: ($info->{Name} => $info->{content})";
                 }
 	    } else {
 		$myinfo{$info->{Name}} = $info->{content};
@@ -216,7 +215,7 @@ OCS::Client - simple interface to OCS's SOAP API
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
